/*
 *  Licensed to the Apache Software Foundation (ASF) under one
 *  or more contributor license agreements.  See the NOTICE file
 *  distributed with this work for additional information
 *  regarding copyright ownership.  The ASF licenses this file
 *  to you under the Apache License, Version 2.0 (the
 *  "License"); you may not use this file except in compliance
 *  with the License.  You may obtain a copy of the License at
 *  
 *    http://www.apache.org/licenses/LICENSE-2.0
 *  
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License. 
 *  
 */

package org.apache.directory.server.dhcp.options.vendor;


import org.apache.directory.server.dhcp.options.StringOption;


/**
 * A string to specify a file, retrievable via TFTP, which contains
 * information which can be interpreted in the same way as the 64-octet
 * vendor-extension field within the BOOTP response, with the following
 * exceptions:
 * 
 *        - the length of the file is unconstrained;
 *        - all references to Tag 18 (i.e., instances of the
 *          BOOTP Extensions Path field) within the file are
 *          ignored.
 * 
 * The code for this option is 18.  Its minimum length is 1.
 *
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 * @version $Rev: 638228 $, $Date: 2008-03-18 08:12:41 +0200 (Tue, 18 Mar 2008) $
 */
public class ExtensionsPath extends StringOption
{
    /*
     * @see org.apache.directory.server.dhcp.options.DhcpOption#getTag()
     */
    public byte getTag()
    {
        return 18;
    }
}
